#
# spec file for package perl-DBD-ODBC
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-DBD-ODBC
Version:        1.61
Release:        2.6
%define cpan_name DBD-ODBC
Summary:        ODBC Driver for DBI
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MJ/MJEVANS/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
Patch0:         perl-DBD-ODBC-1.29-Makefile.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(DBI) >= 1.21
BuildRequires:  perl(Test::Simple) >= 0.90
Requires:       perl(DBI) >= 1.609
Requires:       perl(Test::Simple) >= 0.90
Recommends:     perl(Test::Version) >= 1.002001
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  unixODBC-devel
# MANUAL END

%description
ODBC Driver for DBI

%prep
%autosetup -n %{cpan_name}-%{version}
find . -type f ! -name \*.pl -print0 | xargs -0 chmod 644
# MANUAL BEGIN
for file in README.af README.unicode; do
  perl -p -i -e "s|\r\n|\n|" "$file"
done
pushd examples
#rpmlint: wrong-file-end-of-line-encoding
find -type f -exec perl -p -i -e "s|\r\n|\n|" {} \;
#rpmlint: wrong-script-interpreter
for ex in *; do
  sed -i -e 's,^#!*perl\(.*\),#!/usr/bin/perl\1,' "$ex"
  sed -i -e 's,perl.exe -w,perl -w,' "$ex"
done
popd
# MANUAL END

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes examples FAQ if_you_are_taking_over_this_code.txt README README.adabas README.af README.hpux README.informix README.osx README.RH9 README.sqlserver README.unicode README.windows test_results.txt TO_DO

%changelog
* Wed Feb 21 2024 Michael Vetter <mvetter@suse.com>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Sat Feb  1 2020 Markus Beth <markus.beth@web.de>
- updated to 1.61
  see /usr/share/doc/packages/perl-DBD-ODBC/Changes
  1.61 2020-01-30
    [BUG FIXES]
    Fix 12blob.t test by pali
    Fix searching for ODBC libraries in system by pali (#15)
    [ENHANCEMENTS]
    use PERL_NO_GET_CONTEXT for more performance by markusbeth (#13)
    [MISCELLANEOUS]
    Fix travis builds for older Perls by pali
* Thu Nov  8 2018 Stephan Kulow <coolo@suse.com>
- updated to 1.60
  see /usr/share/doc/packages/perl-DBD-ODBC/Changes
  1.60 2018-10-31
    [BUG FIXES]
    Merged pull request 11 from audun which fixes some issues with the AutoCommit flag
    on commit and rollback.
    [MISCELLANEOUS]
    Merged pull request 10 from vadz which fixed typo (affecting license) in README.md.
* Sat Aug 11 2018 coolo@suse.com
- updated to 1.59
  see /usr/share/doc/packages/perl-DBD-ODBC/Changes
  1.59 2018-08-10
    [BUG FIXES]
    git issue 8. Setting odbc_utf8_on didn't work properly. Thanks to David Wheeler for
    reporting and helping to debug.
* Wed Mar 21 2018 coolo@suse.com
- updated to 1.58
  see /usr/share/doc/packages/perl-DBD-ODBC/Changes
  1.58 2018-03-01
    [MISCELLANEOUS]
    Various changes to the test suite to get better results with Postgres
  1.57 2018-03-01
    [MISCELLANEOUS]
    Merged pull request 6 from genio which allows Makefile.PL argument -u
    to be set via the environment variable DBD_ODBC_UNICODE
    This version was removed from CPAN because it was uploaded with a nasty
    bug in the diagnostics code.
* Fri Mar  2 2018 coolo@suse.com
- updated to 1.57
  see /usr/share/doc/packages/perl-DBD-ODBC/Changes
* Fri Oct  7 2016 coolo@suse.com
- updated to 1.56
  see /usr/share/doc/packages/perl-DBD-ODBC/Changes
  1.56 2016-10-06
    Full release of the 1.53 development series
    One version skipped because of indexing problems.
  1.53_2 2016-02-03
    [MISCELLANEOUS]
    Add new FAQs
  1.53_1 2015-10-16
    [BUG FIXES]
    Strictly speaking this is a bug fix to DBI and not DBD::ODBC but DBI
    now supports 64 bit row counts where an IV in perl is 64 bits. However, it
    necessitated changes to DBD::ODBC to pick up the fix. odbc_rows (my workaround
    since 2012) is still supported but should no longer be required so long as you
    use this DBD::ODBC and DBI 1.633_92 or above.
    [INTERNALS]
    Removed dbd_st_rows and now setting DBIc_ROW_COUNT.
    [DOCUMENTATION]
    Add tables and table_info section to deviations from the DBI spec.
    [MISCELLANEOUS]
    Change column name in t/rt_101579.t as "method" is a reserved word
    in. Teradata Thanks to Zhenyi Zhou.
    Remove duplicate dynamic_config from META.yml.
* Tue Sep  1 2015 coolo@suse.com
- updated to 1.52
  see /usr/share/doc/packages/perl-DBD-ODBC/Changes
  1.52 2015-04-15
    [MISCELLANEOUS]
    Changes to the test suite to make it run better with Postgres thanks
    to Greg Sabino Mullane.
  1.51_4 2015-01-18
    [BUG FIXES]
    Numerous errors in the test suite (with SQLite ODBC driver) mostly down to not
    creating the test table first.
    [MISCELLANEOUS]
    Try and make the test suite run ok for SQLite ODBC driver so I can use it
    in travis-ci.
  1.51_3 2015-01-17
    [BUG FIXES]
    RT101579 - using bound input parameters for numeric columns (e.g.,
    SQL_NUMERIC) only works the first time and will quite likey fail
    with "string data, right truncation" on the second and subsequent
    calls to execute. Thanks to Laura Cox for finding.
  1.51_2 2014-11-19
    [BUG FIXES]
    The table_info method (ANSI version only) was incorrectly passing
    the table name for the type argument. I think this bug was
    introduced last year.
  1.51_1 2014-11-14
    [BUG FIXES]
    RT100186 - handle VARBINARY(MAX) parameters with SQL Server native
    client. Identify "libmsodbcsql*" as the MS ODBC Driver for Linux as
    there are some specific workarounds for MS Native Client ODBC driver.
  1.50 2014-07-25
    [BUG FIXES]
    The 80_odbc_diags.t test could fail if a driver fails a table does
    not exist test in the prepare instead of the execute.
  1.49_4 2014-07-08
    [BUG FIXES]
    Fixed sql_type_cast.t test which assumed column aliases which stay
    lowercase.
    Fixed 87_odbc_lob_read.t test which did not bow out of the test
    properly if the database was not MS SQL Server.
    [DOCUMENTATION]
    Revised the query notification example and documentation.
    Added a link to a better Query Notification article.
  1.49_3 2014-05-01
    [CHANGE IN BEHAVIOUR]
    As warned years ago, this release removes the odbc_old_unicode attribute.
    If you have a good reason to use it speak up now before the next non-development
    release.
    [BUG FIXES]
    Fix rt89255: Fails to create test table for tests using PostgreSQL odbc driver.
    Change test suite to fallback on PRECISION if COLUMN_SIZE is not found.
    [ENHANCEMENTS]
    Added support for MS SQL Server Query Notification. See the new
    section in the pod.
    Added a currently undocumented (and experimental)
    odbc_describe_param method on a statement handle which takes a
    parameter number as the only argument and returns an array of the
    data type, parameter size, decimal digits and nullable (as per
    SQLDescribeParam).
    [DOCUMENTATION]
    Added FAQ on truncated column names with freeTDS.
    [MISCELLANEOUS]
    I have removed the "experimental" tag for odbc_getdiagfield and odbc_getdiagrec
    methods.
  1.49_2 2014-04-26
    [BUG FIXES]
    Change to data_sources in 1.49_1 could lead to a compile error since
    data_sources was not returning a value if an error occurred.
  1.49_1 2014-04-25
    [BUG FIXES]
    If you had a lot of DSNs on Windows (more than 280 but it depends on
    the length of their names) and called the data_sources method it
    could crash your script. Code internally changed to stop putting the DSNs
    returned on the stack.
    [CHANGE IN BEHAVIOUR]
    As warned years ago, the private data_sources method has been
    removed - use DBI one instead.
    [MISCELLANEOUS]
    Added FAQ entry of maximum number of allowed parameters.
* Tue Jul 22 2014 vcizek@suse.com
- refreshed perl-DBD-ODBC-1.29-Makefile.diff
  (it failed to apply after some of the previous updates)
* Mon Mar 17 2014 coolo@suse.com
- updated to 1.48
  [MISCELLANEOUS]
  Manifest has wrong filename for 90_trace_flags.t
  Forgot to remove warning from ODBC.pm that this is a development
  release and unicode change when I released 1.47.
* Mon Feb 24 2014 coolo@suse.com
- updated to 1.47, see Changes for more
  Full release of the 1.46 development releases.
  [MISCELLANEOUS]
  Just some tidying up of dbdimp.c - shouldn't make a difference to anyone.
  Further changes to this change file to make it CPAN::Changes spec.
  NOTE the changes.cpanhq.com site does not yet support "unknown" for
  dates.
  1.46_2 2013-12-17
  [BUG FIXES]
  When built with unicode support and odbc_old_unicode is not enabled
  columns reported as SQL_LONGVARCHAR were not by default bound as
  SQL_WCHAR and hence were not returned correctly unless the bind was
  overridden.
  [MISCELLANEOUS]
  Added test 90_trace_flag.t
  1.46_1 2013-11-16
  [CHANGE IN BEHAVIOUR]
  As warned in release 1.45, the binding of unicode parameters to
  char/varchar columns has changed significantly. If you don't attempt
  to insert unicode into char/varchar columns or if you only inserted
  unicode into nchar/nvarchar columns you should see no difference.
  From this release, unicode data inserted into
  char/varchar/longvarchar columns is bound as SQL_WCHAR and not
  whatever the driver reports the parameter as (which is mostly
  SQL_CHAR).
  Previously if DBD::ODBC received an error or (SQL_SUCCESS_WITH_INFO)
  from an ODBC API call and then the driver refused to return the
  error state/text DBD::ODBC would issue its own error saying "Unable
  to fetch information about the error" and state IM008. That state
  was wrong and has been changed to HY000.
  [BUG FIXES]
  Some drivers cannot support catalogs and/or schema names in
  SQLTables.  Recent changes set the schema/catalog name to the empty
  string (good reasons below) which causes "optional feature not
  implemented" from MS Access (which does not support schemas - even
  for a simply ping (which uses SQLTables)). Now we call
  SQLCATALOG_NAME and SQLSCHEMA_USAGE on connect to ascertain support
  which modifies SQLTables call.
* Tue Nov 26 2013 coolo@suse.com
- updated to 1.45, see Changes for (a lot of) details
* Sat Jul 27 2013 coolo@suse.com
- updated to 1.43, see Changes (a lot)
* Fri Dec  2 2011 vcizek@suse.com
- update to 1.33
  [ENHANCEMENTS]
  * Enable multiple active statement support in 70execute_array.t for
    drivers we recognise which support MAS.
  * Change column_info to support Unicode catalog/schema/table/column
    names.
  * Use SQLGetTypeInfoW on unicode builds.
  * DBD::ODBC now allows unicode catalog/schema/table parameters to be
    passed to table_info. Of course they will only reliably work with
    a supporting Unicode ODBC driver.
  * Added new odbc_driver_complete attribute allowing the ODBC Driver
    Manager and ODBC Driver to throw dialogues for incomplete
    connection strings or expired passwords etc.
  [BUG FIXES]
  * remove debugging printf which output "HERE" in some rare cases.
    rt 72534 - thanks John Deighan for spotting this.
  * The test 70execute_array.t could fail due to warning being output
    if the driver does not support Multiple Active Statements.
  * Fix bug in utf16_copy which was not adding a trailing NUL but I'm
    not sure this affected anyone until I changed table_info this
    release.
  * I omitted rt_68720.t from the 1.31 distribution which leads
    to a warning as it is mentioned in the MANIFEST.
  [DOCUMENTATION]
  * new FAQ entries
  * added note saying you cannot pass unicode schema/table/column
    names to metadata calls like table_info/column_info currently.
  [OTHER]
  * Changed line endings in README.af and README.unicode to be unix
    line endings and native eol-style in subversion.
  * Minor changes to Makefile.PL to save the opensuse guys patching.
  * Added unicode_sql.pl and unicode_params.pl examples
  * added more examples
* Sat Aug 27 2011 chris@computersalat.de
- fix deps
  * perl(Test::Simple) >= 0.88
  * perl(DBI) >= 1.609
* Fri Jun 24 2011 vcizek@novell.com
- update to 1.31
  [ENHANCEMENTS]
  * An extra argument has been added to the sub associated with
  odbc_err_handler.  The arguments passed to the odbc_err_handler are
  now state (string), error (string), native error code (number) and
  the status returned from the last ODBC API. The status will be
  SQL_ERROR (-1) for errors or SQL_SUCCESS_WITH_INFO (1) for
  informational messages.
  * Added support for StrictlyTyped and DiscardString to the bind_col
    method.
  * Added the new odbc_describe_parameters attribute.
  * added -w option to Makefile.PL to add "-Wall" to CCFLAGS and
  - fno-strict-aliasing so I can find warnings.
  * Cope with broken ODBC drivers that describe a parameter as SQL
    type 0.
* Sat Jun 18 2011 coolo@novell.com
- fix requires of examples
- use original tar
* Wed Mar  9 2011 vcizek@novell.com
- update to 1.29
  * Fixed missing SQL_MAX_TABLE_NAME_LEN definition from test.
  * Fixed problem with some drivers which batch "insert;select" where
    SQLMoreResults is not required and an extra describe is done.
  * Fixed "select 1" in 02simple.t for Firebird ODBC Driver.
  * disconnect call added to 70execute_array.t was in the wrong place.
  * Added support for DBI's new trace flags ENC, CON, TXN and
    DBD.
  * And many other fixes and enhancements
* Fri Jan  7 2011 vcizek@novell.com
- update to 1.27
  Minor fix to head in pod
  rt63550 fix and test code and added pod notes on "do"
  snprintf buffer overflow when GetTypeInfo values are negative
  capture execute error in rt_62033.t
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Thu Sep 23 2010 anicka@suse.cz
- update to 1.25
  * Changed bind_col so it actually pays attention to the TYPE
  attribute as you could not override the bind type of a bound
    column before.
  * Left a sv_undef in
  * Change sprintf to snprintf for safety.
  * Removed some unused fields from the fbh structure which should
  save a little memory for each column in a result-set.
  * Started adding support for DBI's DiscardString and StrictlyTyped
  but not complete yet so don't use them yet.
  * Added experimental odbc_lob_read method - see pod.
  * Moved the binding of columns to the first call to fetch instead of
  after execute is called as it prevents bind_col overrriding the
  type used for binding and I needed it to support odbc_lob_read.
  * Removed support for DBI's blob_read - it was totally flawed and
  did not work at all. May replace in the future.
  * Added support for MS SQL Server XML type (SQL type -152).
  * bugfixes, new FAQs
* Sun Jul 25 2010 chris@computersalat.de
- removed dos2unix usage
* Thu Jun  3 2010 chris@computersalat.de
  update to 1.24
  o please see Changes file
- recreated spec by cpanspec 1.78
- added examples to doc
* Fri Feb 26 2010 anicka@suse.cz
- update to 1.23
  * bugfixes, test fixes
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Aug  3 2009 anicka@suse.cz
- update to 1.22
  * bugfixes
* Mon May 18 2009 anicka@suse.cz
- update to 1.21
  * bugfixes, documentation fixes
* Tue Apr 28 2009 anicka@suse.cz
- update to 1.20
  * bugfixes, test fixes
* Mon Apr  6 2009 anicka@suse.cz
- update to 1.19
  * test fixes
* Tue Jan 20 2009 anicka@suse.cz
- update to 1.18
  * bugfixes, test fixes
* Mon Oct  6 2008 anicka@suse.cz
- update to 1.17
  * Changed default fallback parameter bind type to SQL_WVARCHAR for
  unicode builds. This affects ODBC drivers which don't have
  * About a 30%% rewrite of bound parameter code which started with an
  attempt to support the new VARBINARY(MAX) and VARCHAR(MAX)
  columns in SQL Server when the parameter length is > 400K in size
  * Rewrote ColAttributes code to understand string and numeric
  attributes rather than trying to guess by what the driver returns.
  * bugfixes, test fixes
* Fri Jun 27 2008 anicka@suse.cz
- update to 1.16
  * More tracing in dbdimp.c for named parameters.
  * #ifdeffed out odbc_get_primary_keys in dbdimp.c as it is no
  longer used.  $h->func($catalog, $schema, $table, 'GetPrimaryKeys')
  ends up in dbdimp.c/dbd_st_primary_keys now.
  * Changes to Makefile.PL to fix a newly introduced bug with 'tr',
  remove easysoft OOB detection and to try and use odbc_config and
  odbcinst if we find them to aid automatic configuration. This
  latter change also adds "odbc_config --cflags" to the CC line
  when building DBD::ODBC.
  * Added support for parse_trace_flag and parse_trace_flags methods
  and defined a DBD::ODBC private flag 'odbcdev' as a test case.
  * Add support for the 'SQL' trace type. Added private trace type
  odbcdev as an experimental start.
  * Change odbc_query_timeout attribute handling so if it is set to 0
  after having set it to a non-zero value the default of no time
  out is restored.
  * Added support for DBI's statistics_info method.
  * test changes, documentation changes, bugfixes
- remove -uninitialized patch (fixed in upstream)
* Thu Mar 13 2008 anicka@suse.cz
- update to 1.15
  * DBI->connect changed so informational diagnostics like "Changed
  database context to 'master'" from SQL Server are available in
  errstr/state.
  * Changed Makefile.PL to attempt to find unixODBC if -o or ODBCHOME
  not specified.
  * Fairly major changes to dbd_describe in dbdimp.c to reduce ODBC
  calls by 1 SQLDescribeCol call per column when describing result
  sets.
  * Changed to avoid using explicit use of DBIc_ERRXXX in favour
  of newish DBIh_SET_ERR_CHAR.
  * test fixes, bugfixes, documentation added
* Wed Jul 25 2007 anicka@suse.cz
- update to 1.14
  * Add array parameter binding (per new DBI Spec)
  * Add row caching/multiple row fetches to speed selects
  * Better/more tests on multiple statement handles which ensure
    the correct number of rows
  * Better/more tests on all queries which ensure the correct
    number of rows and data
  * Better tests on SQLExecDirect/do
  * Keep checking Oracle's ODBC drivers for Windows to fix
    the Date binding problem
  * Change SQLColAttributes calls (now deprecated)
    to SQLColAttribute
  * Add support for $sth->more_results based on DBD::ODBC-specific
    attribute
  * Removed some unused variable declarations leading to warnings.
  * Removed PerlIO_flush calls as it is believed they are not
    required.
  * Add logging for whether SQLDescribeParam is supported.
  * Add provisional Unicode support. This change is very
    experimental (especially on UNIX). Please see ODBC.pm
    documentation.
  * Updated FAQ, added a few more questions etc.
  * DBD::ODBC requires at least 5.6.0 of Perl.
  * bugfixes, test fixes, documentation fixes
* Fri Feb 16 2007 anicka@suse.cz
- update to 1.13
  * Make ODBC version 3.0 default!
  * Document more of the DBD::ODBC private attributes/functions.
  * Add array parameter binding (per new DBI Spec)
  * Add row caching/multiple row fetches to speed selects
  * Better/more tests on multiple statement handles which ensure
    the correct number of rows
  * Better/more tests on all queries which ensure the correct number
    of rows and data
  * Better tests on SQLExecDirect/do
  * Change default behaviour to use SQLDescribeParam instead of
    SQL_VARCHAR.
  * Fix inconsistency/bug with odbc_exec_direct vs. odbc_execdirect
    settings.
  * Fix handling of print statements for SQL Server.
  * Due to bug in SQL Server, you must use odbc_exec_direct.
  * Change tests to use Test::More.
  * Added odbc_timeout, but untested
  * Added pod.t test, taken from DBI.
  * Change to use dbivport.h per new DBI spec.
  * Add ability to set the cursor type during the connect.
  * many bugfixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Oct  4 2005 dmueller@suse.de
- add norootforbuild
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Jul 21 2003 stark@suse.de
- use vendorarch instead of vendorlib
* Thu Jul 17 2003 stark@suse.de
- use new conventions for perl 5.8.1
* Mon Jul  7 2003 stark@suse.de
- update to 1.06
- fixed Makefile.PL
  * add OPTIMIZE
  * fixed usage of $Config{lib_ext}
- workaround for broken generated Makefile
* Thu Jun 19 2003 stark@suse.de
- added DBD directories to filelist
* Mon May 19 2003 stark@suse.de
- removed unwanted files from buildroot
* Tue Apr 22 2003 stark@suse.de
- update to 1.05
* Tue Feb 11 2003 stark@suse.de
- update to 1.04
* Tue Dec 17 2002 stark@suse.de
- update to 1.01
* Wed Nov 27 2002 prehak@suse.cz
- fixed libdir in Makefile.PL
- enabled make test
* Wed Sep 18 2002 stark@suse.de
- initial package
